"""Google Sheets Refunds app constants"""

SHEET_TYPE_ENROLL_CHANGE = "enrollchange"
WORKSHEET_TYPE_REFUND = "refund"

REQUIRED_GOOGLE_SHEETS_REFUNDS_SETTINGS = [
    "MITOL_GOOGLE_SHEETS_REFUNDS_REQUEST_WORKSHEET_ID",
    "MITOL_GOOGLE_SHEETS_REFUNDS_PLUGINS",
]
